@@ -29,13 +29,14 @@ def check_connection(url: str, logger=None):
 
 
 def wait_until_server_is_online(url, logger, sleep_time: int = 2, retries: int = 15) -> None:
-    for _ in range(retries):
+    while(True):
         try:
             check_connection(url, logger)
-        except ConnectionError as e:
-            time.sleep(sleep_time)
+            break
+        except (socket.gaierror, ConnectionError) as e:
             if logger != None:
-                logger.info(f"Try again to reconnect to server {url}")
+                logger.info(f"During trying connect to {url} following error accrued: {e}. Try again to connect in {sleep_time} sec.")
+            time.sleep(sleep_time)
 
 
 def generate_unique_id():
